==> green-core-1.65.2.tgz: package/components/textarea/textarea.js <==
import {
  GdsTextarea
} from "../../chunks/chunk.IVF6XCAV.js";
import "../../chunks/chunk.VHN4JEZC.js";
import "../../chunks/chunk.VZTV63IQ.js";
import "../../chunks/chunk.7GC6JLT5.js";
import "../../chunks/chunk.33KNAKAX.js";
import "../../chunks/chunk.VHLWBCJK.js";
import "../../chunks/chunk.HO2KZJXR.js";
import "../../chunks/chunk.2BJVQ5WE.js";
import "../../chunks/chunk.S3FBHJYG.js";
import "../../chunks/chunk.H4QXCNY2.js";
import "../../chunks/chunk.IVRW42EY.js";
import "../../chunks/chunk.ALFDKEVN.js";
import "../../chunks/chunk.ZJAOT2TY.js";
import "../../chunks/chunk.GUAH7AIO.js";
import "../../chunks/chunk.CK2UGCPG.js";
import "../../chunks/chunk.AOTGGABX.js";
import "../../chunks/chunk.3M4XRCEF.js";
import "../../chunks/chunk.5SFGYE7C.js";
import "../../chunks/chunk.WFKUYHQY.js";
import "../../chunks/chunk.N4DG6Q7H.js";
import "../../chunks/chunk.K4KPKUH4.js";
import "../../chunks/chunk.JGTSJ4J6.js";
import "../../chunks/chunk.5KH5FC7L.js";
import "../../chunks/chunk.TX64TTBN.js";
import "../../chunks/chunk.I26S7X2I.js";
import "../../chunks/chunk.VA6TUMR2.js";
import "../../chunks/chunk.WM7HBMMV.js";
import "../../chunks/chunk.S6H4MUKG.js";
import "../../chunks/chunk.TYGMNHNO.js";
import "../../chunks/chunk.YO24ZYAD.js";
import "../../chunks/chunk.L2TDNB6Z.js";
import "../../chunks/chunk.6QMJ7GQK.js";
import "../../chunks/chunk.TMEWQZER.js";
import "../../chunks/chunk.QK3R23GV.js";
import "../../chunks/chunk.B7ZOSVCQ.js";
import "../../chunks/chunk.SEHSDSX2.js";
export {
  GdsTextarea
};

==> green-core-1.66.0.tgz: package/components/textarea/textarea.js <==
import {
  GdsTextarea
} from "../../chunks/chunk.FHNILNLX.js";
import "../../chunks/chunk.VHN4JEZC.js";
import "../../chunks/chunk.VZTV63IQ.js";
import "../../chunks/chunk.VHLWBCJK.js";
import "../../chunks/chunk.7GC6JLT5.js";
import "../../chunks/chunk.2BJVQ5WE.js";
import "../../chunks/chunk.BCTJIMKU.js";
import "../../chunks/chunk.HO2KZJXR.js";
import "../../chunks/chunk.S3FBHJYG.js";
import "../../chunks/chunk.H4QXCNY2.js";
import "../../chunks/chunk.IVRW42EY.js";
import "../../chunks/chunk.ALFDKEVN.js";
import "../../chunks/chunk.6IPE43TE.js";
import "../../chunks/chunk.GUAH7AIO.js";
import "../../chunks/chunk.CK2UGCPG.js";
import "../../chunks/chunk.PZHMIVFF.js";
import "../../chunks/chunk.3M4XRCEF.js";
import "../../chunks/chunk.UGHZGD2M.js";
import "../../chunks/chunk.M5C2HLKD.js";
import "../../chunks/chunk.C6D7M75U.js";
import "../../chunks/chunk.JGTSJ4J6.js";
import "../../chunks/chunk.B3QCLV6X.js";
import "../../chunks/chunk.TX64TTBN.js";
import "../../chunks/chunk.ESW6XPZT.js";
import "../../chunks/chunk.VA6TUMR2.js";
import "../../chunks/chunk.WM7HBMMV.js";
import "../../chunks/chunk.G2WTHFPE.js";
import "../../chunks/chunk.76QWARGM.js";
import "../../chunks/chunk.NUUST5OZ.js";
import "../../chunks/chunk.LNQWCKU7.js";
import "../../chunks/chunk.TYGMNHNO.js";
import "../../chunks/chunk.WBBCGR25.js";
import "../../chunks/chunk.6QMJ7GQK.js";
import "../../chunks/chunk.YO24ZYAD.js";
import "../../chunks/chunk.TMEWQZER.js";
import "../../chunks/chunk.QK3R23GV.js";
import "../../chunks/chunk.B7ZOSVCQ.js";
import "../../chunks/chunk.SEHSDSX2.js";
export {
  GdsTextarea
};
